module Ugrp
  module Api
    class DomainsController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_domain, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_domain, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #

      # GET /domains/:domain_id/users.xml
      # GET /domains/:domain_id/users.json
      # def index
      #   @domains = Ugrp::Domain.all

      #   respond_to do |format|
      #     format.xml  { render :xml  => @domains }
      #     format.json { render json: @domains }
      #   end
      # end

      #
      # Standard CRUD methods
      #

      # GET /domains.xml
      # GET /domains.json
      def index
        @domains = Ugrp::Domain.all

        respond_to do |format|
          format.xml  { render xml: @domains }
          format.json { render json: @domains }
        end
      end

      # GET /domains/1.xml
      # GET /domains/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @domain }
          format.json { render json: @domain }
        end
      end

      # GET /domains/new.xml
      # GET /domains/new.json
      def new
        @domain = Ugrp::Domain.new

        respond_to do |format|
          format.xml  { render xml: @domain }
          format.json { render json: @domain }
        end
      end

      # GET /domains/1/edit
      def edit
      end

      # POST /domains.xml
      # POST /domains.json
      def create
        @domain = Ugrp::Domain.new(domain_params)

        respond_to do |format|
          if @domain.save
            format.xml  { render xml: @domain, status: :created, location: @domain }
            format.json { render json: @domain, status: :created, location: @domain }
          else
            format.xml  { render xml: @domain.errors, status: :unprocessable_entity }
            format.json { render json: @domain.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /domains/1.xml
      # PUT /domains/1.json
      def update
        respond_to do |format|
          if @domain.update(domain_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @domain.errors, status: :unprocessable_entity }
            format.json { render json: @domain.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /domains/1.xml
      # DELETE /domains/1.json
      def destroy
        @domain.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_domain
        @domain = Ugrp::Domain.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def domain_params
        params.require(:domain).permit(
          :url, :name, :default_locale, :is_active,
          :owner, :owner_id, :owner_type
        )
      end
    end
  end
end
