module Ugrp
  module Api
    class GroupsController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_group, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_group, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #

      #
      # Standard CRUD methods
      #

      # GET /groups.xml
      # GET /groups.json
      def index
        @groups = Ugrp::Group.all

        respond_to do |format|
          format.xml  { render xml: @groups }
          format.json { render json: @groups }
        end
      end

      # GET /groups/1.xml
      # GET /groups/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @group }
          format.json { render json: @group }
        end
      end

      # GET /groups/new.xml
      # GET /groups/new.json
      def new
        @group = Ugrp::Group.new

        respond_to do |format|
          format.xml  { render xml: @group }
          format.json { render json: @group }
        end
      end

      # GET /groups/1/edit
      def edit
      end

      # POST /groups.xml
      # POST /groups.json
      def create
        @group = Ugrp::Group.new(group_params)

        respond_to do |format|
          if @group.save
            format.xml  { render xml: @group, status: :created, location: @group }
            format.json { render json: @group, status: :created, location: @group }
          else
            format.xml  { render xml: @group.errors, status: :unprocessable_entity }
            format.json { render json: @group.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /groups/1.xml
      # PUT /groups/1.json
      def update
        respond_to do |format|
          if @group.update(group_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @group.errors, status: :unprocessable_entity }
            format.json { render json: @group.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /groups/1.xml
      # DELETE /groups/1.json
      def destroy
        @group.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_group
        @group = Ugrp::Group.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def group_params
        params.require(:group).permit(
          :group, :group_id,
          :name, :descriptive_name, :is_active
        )
      end
    end
  end
end
