module Ugrp
  module Api
    class PermissionsController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_permission, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_permission, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #

      #
      # Standard CRUD methods
      #

      # GET /permissions.xml
      # GET /permissions.json
      def index
        @permissions = Ugrp::Permission.all

        respond_to do |format|
          format.xml  { render xml: @permissions }
          format.json { render json: @permissions }
        end
      end

      # GET /permissions/1.xml
      # GET /permissions/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @permission }
          format.json { render json: @permission }
        end
      end

      # GET /permissions/new.xml
      # GET /permissions/new.json
      def new
        @permission = Ugrp::Permission.new

        respond_to do |format|
          format.xml  { render xml: @permission }
          format.json { render json: @permission }
        end
      end

      # GET /permissions/1/edit
      def edit
      end

      # POST /permissions.xml
      # POST /permissions.json
      def create
        @permission = Ugrp::Permission.new(permission_params)

        respond_to do |format|
          if @permission.save
            format.xml  { render xml: @permission, status: :created, location: @permission }
            format.json { render json: @permission, status: :created, location: @permission }
          else
            format.xml  { render xml: @permission.errors, status: :unprocessable_entity }
            format.json { render json: @permission.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /permissions/1.xml
      # PUT /permissions/1.json
      def update
        respond_to do |format|
          if @permission.update(permission_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @permission.errors, status: :unprocessable_entity }
            format.json { render json: @permission.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /permissions/1.xml
      # DELETE /permissions/1.json
      def destroy
        @permission.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_permission
        @permission = Ugrp::Permission.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def permission_params
        params.require(:permission).permit(
          :permission, :permission_id,
          :name, :descriptive_name, :is_active
        )
      end
    end
  end
end
