module Ugrp
  module Api
    class RolesController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_role, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_role, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #

      #
      # Standard CRUD methods
      #

      # GET /roles.xml
      # GET /roles.json
      def index
        @roles = Ugrp::Role.all

        respond_to do |format|
          format.xml  { render xml: @roles }
          format.json { render json: @roles }
        end
      end

      # GET /roles/1.xml
      # GET /roles/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @role }
          format.json { render json: @role }
        end
      end

      # GET /roles/new.xml
      # GET /roles/new.json
      def new
        @role = Ugrp::Role.new

        respond_to do |format|
          format.xml  { render xml: @role }
          format.json { render json: @role }
        end
      end

      # GET /roles/1/edit
      def edit
      end

      # POST /roles.xml
      # POST /roles.json
      def create
        @role = Ugrp::Role.new(role_params)

        respond_to do |format|
          if @role.save
            format.xml  { render xml: @role, status: :created, location: @role }
            format.json { render json: @role, status: :created, location: @role }
          else
            format.xml  { render xml: @role.errors, status: :unprocessable_entity }
            format.json { render json: @role.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /roles/1.xml
      # PUT /roles/1.json
      def update
        respond_to do |format|
          if @role.update(role_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @role.errors, status: :unprocessable_entity }
            format.json { render json: @role.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /roles/1.xml
      # DELETE /roles/1.json
      def destroy
        @role.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_role
        @role = Ugrp::Role.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def role_params
        params.require(:role).permit(
          :role, :role_id,
          :name, :descriptive_name, :is_active
        )
      end
    end
  end
end
