module Ugrp
  module Api
    class UserPreferencesController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_user_preference, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_user_preference, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #

      #
      # Standard CRUD methods
      #

      # GET /user_preferences.xml
      # GET /user_preferences.json
      def index
        @user_preferences = Ugrp::UserPreference.all

        respond_to do |format|
          format.xml  { render xml: @user_preferences }
          format.json { render json: @user_preferences }
        end
      end

      # GET /user_preferences/1.xml
      # GET /user_preferences/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @user_preference }
          format.json { render json: @user_preference }
        end
      end

      # GET /user_preferences/new.xml
      # GET /user_preferences/new.json
      def new
        @user_preference = Ugrp::UserPreference.new

        respond_to do |format|
          format.xml  { render xml: @user_preference }
          format.json { render json: @user_preference }
        end
      end

      # GET /user_preferences/1/edit
      def edit
      end

      # POST /user_preferences.xml
      # POST /user_preferences.json
      def create
        @user_preference = Ugrp::UserPreference.new(user_preference_params)

        respond_to do |format|
          if @user_preference.save
            format.xml  { render xml: @user_preference, status: :created, location: @user_preference }
            format.json { render json: @user_preference, status: :created, location: @user_preference }
          else
            format.xml  { render xml: @user_preference.errors, status: :unprocessable_entity }
            format.json { render json: @user_preference.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /user_preferences/1.xml
      # PUT /user_preferences/1.json
      def update
        respond_to do |format|
          if @user_preference.update(user_preference_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @user_preference.errors, status: :unprocessable_entity }
            format.json { render json: @user_preference.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /user_preferences/1.xml
      # DELETE /user_preferences/1.json
      def destroy
        @user_preference.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_user_preference
        @user_preference = UserPreference.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def user_preference_params
        params.require(:user_preference).permit(
          :user, :user_id,
          :key, :value
        )
      end
    end
  end
end
