module Ugrp
  module Api
    class UsersController < ApiController
      if Rails.version.to_f >= 5.1
        # before_action :authenticate_user!
        before_action :set_user, only: [:show, :edit, :update, :destroy]
      else
        # before_filter :authenticate_user!
        before_filter :set_user, only: [:show, :edit, :update, :destroy]
      end

      #
      # Nested CRUD methods
      #
      def authenticate_user(_user_reference, _password)
        sign_in user, bypass: true
      end

      #
      # Standard CRUD methods
      #

      # GET /users.xml
      # GET /users.json
      # GET /domains/:domain_id/users.xml
      # GET /domains/:domain_id/users.json
      def index
        domain_id = params[:domain_id]
        @users = if domain_id.blank?
                   Ugrp::User.all
                 elsif domain_id.to_i.positive?
                   domain = Ugrp::Domain.where(id: domain_id.to_i)
                   domain.blank? ? [] : domain.first.users
                 else
                   domain = Ugrp::Domain.where(name: domain_id)
                   domain.blank? ? [] : domain.first.users
                 end

        respond_to do |format|
          format.xml  { render xml: @users }
          format.json { render json: @users }
        end
      end

      # GET /users/1.xml
      # GET /users/1.json
      # GET /domains/:domain_id/1.xml
      # GET /domains/:domain_id/1.json
      def show
        respond_to do |format|
          format.xml  { render xml: @user }
          format.json { render json: @user }
        end
      end

      # GET /users/new.xml
      # GET /users/new.json
      # GET /domains/:domain_id/new.xml
      # GET /domains/:domain_id/new.json
      def new
        @user = Ugrp::User.new

        respond_to do |format|
          format.xml  { render xml: @user }
          format.json { render json: @user }
        end
      end

      # GET /users/1/edit
      # GET /domains/:domain_id/users/1/edit
      def edit
      end

      # POST /users.xml
      # POST /users.json
      # POST /domains/:domain_id/users.xml
      # POST /domains/:domain_id/users.json
      def create
        @user = Ugrp::User.new(user_params)

        respond_to do |format|
          if @user.save
            format.xml  { render xml: @user, status: :created, location: @user }
            format.json { render json: @user, status: :created, location: @user }
          else
            format.xml  { render xml: @user.errors, status: :unprocessable_entity }
            format.json { render json: @user.errors, status: :unprocessable_entity }
          end
        end
      end

      # PUT /users/1.xml
      # PUT /users/1.json
      # GET /domains/:domain_id/users/1.xml
      # GET /domains/:domain_id/users/1.json
      def update
        respond_to do |format|
          if @user.update(user_params)
            format.xml  { head :no_content }
            format.json { head :no_content }
          else
            format.xml  { render xml: @user.errors, status: :unprocessable_entity }
            format.json { render json: @user.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /users/1.xml
      # DELETE /users/1.json
      # DELETE /domains/:domain_id/users/1.xml
      # DELETE /domains/:domain_id/users/1.json
      def destroy
        @user.destroy

        respond_to do |format|
          format.xml  { head :no_content }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_user
        # user_id = params[:id].nil? || params[:id].to_i.zero? ? Ugrp::User.current_user.id : params[:id]
        user_id = params[:id].nil? || params[:id].to_i.zero? ? current_user.id : params[:id]
        @user = Ugrp::User.find(user_id)
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def user_params
        params.require(:user).permit(
          :username, :display_name,
          :login, :name, :email,
          :password, :password_confirmation, :encrypted_password,
          :remember_me, :confirmed_at
        )
      end
    end
  end
end
