require_dependency "ugrp/ugrp_controller"

module Ugrp
  class DomainsController < ApplicationController
    if Rails.version.to_f >= 5.1
      # before_action :authenticate_user!
      before_action :set_domain, only: [:show, :edit, :update, :destroy]
    else
      # before_filter :authenticate_user!
      before_filter :set_domain, only: [:show, :edit, :update, :destroy]
    end

    # GET /domains
    # GET /domains.json
    def index
      @domains = Ugrp::Domain.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @domains }
      end
    end

    # GET /domains/1
    # GET /domains/1.json
    def show
      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @domain }
      end
    end

    # GET /domains/new
    # GET /domains/new.json
    def new
      @domain = Ugrp::Domain.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @domain }
      end
    end

    # GET /domains/1/edit
    def edit
    end

    # POST /domains
    # POST /domains.json
    def create
      @domain = Ugrp::Domain.new(domain_params)

      respond_to do |format|
        if @domain.save
          format.html { redirect_to domain_path(@domain), notice: 'Domain was successfully created.' }
          format.json { render json: @domain, status: :created, location: @domain }
        else
          format.html { render action: "new" }
          format.json { render json: @domain.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /domains/1
    # PUT /domains/1.json
    def update
      respond_to do |format|
        if @domain.update_attributes(domain_params)
          format.html { redirect_to domain_path(@domain), notice: 'Domain was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @domain.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /domains/1
    # DELETE /domains/1.json
    def destroy
      @domain.destroy

      respond_to do |format|
        format.html { redirect_to domains_url }
        format.json { head :no_content }
      end
    end

    private

      # Use callbacks to share common setup or constraints between actions.
      def set_domain
        @domain = Ugrp::Domain.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def domain_params
        params.require(:domain).permit(
          :url, :name, :default_locale, :is_active,
          :owner, :owner_id, :owner_type
        )
      end
  end
end
