require_dependency "ugrp/ugrp_controller"

module Ugrp
  class GroupsController < ApplicationController
    if Rails.version.to_f >= 5.1
      # before_action :authenticate_user!
      before_action :set_group, only: [:show, :edit, :update, :destroy]
    else
      # before_filter :authenticate_user!
      before_filter :set_group, only: [:show, :edit, :update, :destroy]
    end

    # GET /groups
    # GET /groups.json
    def index
      @groups = Ugrp::Group.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @groups }
      end
    end

    # GET /groups/1
    # GET /groups/1.json
    def show
      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @group }
      end
    end

    # GET /groups/new
    # GET /groups/new.json
    def new
      @group = Ugrp::Group.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @group }
      end
    end

    # GET /groups/1/edit
    def edit
    end

    # POST /groups
    # POST /groups.json
    def create
      @group = Ugrp::Group.new(group_params)

      respond_to do |format|
        if @group.save
          format.html { redirect_to group_path(@group), notice: 'Group was successfully created.' }
          format.json { render json: @group, status: :created, location: @group }
        else
          format.html { render action: "new" }
          format.json { render json: @group.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /groups/1
    # PUT /groups/1.json
    def update
      respond_to do |format|
        if @group.update_attributes(group_params)
          format.html { redirect_to group_path(@group), notice: 'Group was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @group.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /groups/1
    # DELETE /groups/1.json
    def destroy
      @group.destroy

      respond_to do |format|
        format.html { redirect_to groups_url }
        format.json { head :no_content }
      end
    end

    private

      # Use callbacks to share common setup or constraints between actions.
      def set_group
        @group = Ugrp::Group.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def group_params
        params.require(:group).permit(
          :domain, :domain_id,
          :name, :descriptive_name, :is_active
        )
      end
  end
end
