require_dependency "ugrp/ugrp_controller"

module Ugrp
  class PermissionsController < ApplicationController
    if Rails.version.to_f >= 5.1
      # before_action :authenticate_user!
      before_action :set_permission, only: [:show, :edit, :update, :destroy]
    else
      # before_filter :authenticate_user!
      before_filter :set_permission, only: [:show, :edit, :update, :destroy]
    end

    # GET /permissions
    # GET /permissions.json
    def index
      @permissions = Ugrp::Permission.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @permissions }
      end
    end

    # GET /permissions/1
    # GET /permissions/1.json
    def show
      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @permission }
      end
    end

    # GET /permissions/new
    # GET /permissions/new.json
    def new
      @permission = Ugrp::Permission.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @permission }
      end
    end

    # GET /permissions/1/edit
    def edit
    end

    # POST /permissions
    # POST /permissions.json
    def create
      @permission = Ugrp::Permission.new(permission_params)

      respond_to do |format|
        if @permission.save
          format.html { redirect_to permission_path(@permission), notice: 'Permission was successfully created.' }
          format.json { render json: @permission, status: :created, location: @permission }
        else
          format.html { render action: "new" }
          format.json { render json: @permission.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /permissions/1
    # PUT /permissions/1.json
    def update
      respond_to do |format|
        if @permission.update_attributes(permission_params)
          format.html { redirect_to permission_path(@permission), notice: 'Permission was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @permission.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /permissions/1
    # DELETE /permissions/1.json
    def destroy
      @permission.destroy

      respond_to do |format|
        format.html { redirect_to permissions_url }
        format.json { head :no_content }
      end
    end

    private

      # Use callbacks to share common setup or constraints between actions.
      def set_permission
        @permission = Ugrp::Permission.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def permission_params
        params.require(:permission).permit(
          :domain, :domain_id,
          :name, :descriptive_name, :is_active
        )
      end
  end
end
