require_dependency "ugrp/ugrp_controller"

module Ugrp
  class RolesController < ApplicationController
    if Rails.version.to_f >= 5.1
      # before_action :authenticate_user!
      before_action :set_role, only: [:show, :edit, :update, :destroy]
    else
      # before_filter :authenticate_user!
      before_filter :set_role, only: [:show, :edit, :update, :destroy]
    end

    # GET /roles
    # GET /roles.json
    def index
      @roles = Ugrp::Role.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @roles }
      end
    end

    # GET /roles/1
    # GET /roles/1.json
    def show
      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @role }
      end
    end

    # GET /roles/new
    # GET /roles/new.json
    def new
      @role = Ugrp::Role.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @role }
      end
    end

    # GET /roles/1/edit
    def edit
    end

    # POST /roles
    # POST /roles.json
    def create
      @role = Ugrp::Role.new(role_params)

      respond_to do |format|
        if @role.save
          format.html { redirect_to role_path(@role), notice: 'Role was successfully created.' }
          format.json { render json: @role, status: :created, location: @role }
        else
          format.html { render action: "new" }
          format.json { render json: @role.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /roles/1
    # PUT /roles/1.json
    def update
      respond_to do |format|
        if @role.update_attributes(role_params)
          format.html { redirect_to role_path(@role), notice: 'Role was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @role.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /roles/1
    # DELETE /roles/1.json
    def destroy
      @role.destroy

      respond_to do |format|
        format.html { redirect_to roles_url }
        format.json { head :no_content }
      end
    end

    private

      # Use callbacks to share common setup or constraints between actions.
      def set_role
        @role = Ugrp::Role.find(params[:id])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def role_params
        params.require(:role).permit(
          :domain, :domain_id,
          :name, :descriptive_name, :is_active
        )
      end
  end
end
