require 'cancan'

module Ugrp
  # class UgrpController < Ugrp.parent_controller.constantize
  class UgrpController < ::ApplicationController
    rescue_from ::CanCan::AccessDenied do |exception|
      if current_user.nil? # user is not logged in
        session[:next] = request.fullpath
        redirect_to login_url, alert: I18n.t('ugrp.login_to_continue')
      elsif request.env['HTTP_REFERER'].present?
        redirect_to request.env['HTTP_REFERER'], alert: exception.message
      else
        render file: "#{Rails.public_path.join('403.html')}", status: :forbidden, layout: false
      end
    end

    #---------------------------------------------------------------------------

    protect_from_forgery

    helper Ugrp::UgrpHelper
    helper Ugrp::UserPreferencesHelper
    helper Ugrp::UsersHelper

    #---------------------------------------------------------------------------

    # Rack and Rails < 3 do not use encodings correctly
    if Rails.version.to_f <= 4.0
      before_filter :params_filter

      def params_filter
        return unless RUBY_VERSION >= '1.9' && defined?(Rails) && Rails::VERSION::MAJOR < 3

        utf8nize!(params)
      end
    end

    def utf8nize!(obj)
      if obj.frozen?
        obj
      elsif obj.is_a? String
        obj.respond_to?(:force_encoding) ? obj.force_encoding("UTF-8") : obj
      elsif obj.is_a? Hash
        obj.each { |k, v| obj[k] = utf8nize!(v) }
      elsif obj.is_a? Array
        obj.each { |v| utf8nize!(v) }
      else
        obj
      end
    end

    #---------------------------------------------------------------------------

    def back_url
      params[:back_url] || request.env['HTTP_REFERER']
    end

    def redirect_back_or_default(default, alert)
      back_uri = CGI.unescape(back_url.to_s)
      if back_uri.present?
        begin
          uri = URI.parse(back_uri)
          # do not redirect user to another host or to the login or registration page
          if (uri.relative? || (uri.host == request.host)) && !uri.path.match(%r{/(login|sign_in|register|sign_up)$})
            redirect_to back_uri, alert: alert
            return
          end
        rescue URI::InvalidURIError
          # redirect to default
        end
      end

      redirect_to default, alert: alert
      false
    end
  end
end
