# frozen_string_literal: true

require_dependency 'ugrp/ugrp_controller'
require 'devise/version'

# Extend ::Devise::PasswordsController
module Ugrp
  module Users
    class PasswordsController < Devise::PasswordsController
      include Recaptcha::Adapters::ControllerMethods

      # Change this to be any actions you want to protect.
      # prepend_before_action :check_captcha, only: [:create] #, unless: ::Recaptcha.configuration.site_key.nil?

      # POST /resource/password
      def create
        recaptcha_valid = ::Recaptcha.configuration.site_key.nil? || verify_recaptcha(model: @user, action: 'password_reset')
        if recaptcha_valid
          super
        else
          flash.now[:error] = 'Recaptcha Human Check Failed'
          redirect_to new_user_password_path
        end
      end

      # PATCH /resource/password
      # PUT   /resource/password
      def update
        recaptcha_valid = ::Recaptcha.configuration.site_key.nil? || verify_recaptcha(model: @user, action: 'password_change')
        if recaptcha_valid
          super
        else
          flash.now[:error] = 'Recaptcha Human Check Failed'
          redirect_to edit_user_password_path
        end
      end

      private

      def check_captcha
        return if verify_recaptcha

        self.resource = resource_class.new
        respond_with_navigational(resource) { render :new }
      end
    end
  end
end
