# frozen_string_literal: true

require_dependency 'ugrp/ugrp_controller'
require 'devise/version'

# Extend ::Devise::RegistrationsController
module Ugrp
  module Users
    class RegistrationsController < ::Devise::RegistrationsController
      include Recaptcha::Adapters::ControllerMethods

      if ::Devise::VERSION.to_f >= 5.0
        # prepend_before_action :configure_permitted_parameters, if: :devise_controller?
        # prepend_before_action :check_captcha, only: [:create] # , unless: ::Recaptcha.configuration.site_key.nil? # Change this to be any actions you want to protect.
      elsif ::Devise::VERSION.to_f >= 4.3
        prepend_before_action :check_captcha, only: [:create] # Change this to be any actions you want to protect.
        before_action :configure_permitted_parameters, if: :devise_controller?
        # before_action :check_captcha, only: [:create] # , unless: ::Recaptcha.configuration.site_key.nil? # Change this to be any actions you want to protect.
      else
        before_filter :configure_permitted_parameters_old, if: :devise_controller?
        # before_filter :check_captcha, only: [:create] # , unless: ::Recaptcha.configuration.site_key.nil? # Change this to be any actions you want to protect.
      end

      # POST /resource/register
      def create
        recaptcha_valid = true ||
                          ::Recaptcha.configuration.site_key.nil? ||
                          verify_recaptcha(model: @user, action: 'registration')

        if recaptcha_valid
          super
        else
          flash.now[:error] = 'Recaptcha Human Check Failed'
          redirect_to new_user_registration_path
        end
      end

      protected

      def configure_permitted_parameters_old
        devise_parameter_sanitizer.for(:sign_up).push(:login, :username, :name, :email)
      end

      def configure_permitted_parameters
        devise_parameter_sanitizer.permit(:sign_up, keys: [:username, :name, :email])

        devise_parameter_sanitizer.permit(:sign_in) do |user_params|
          user_params.permit(:username, :email, :password)
        end
      end

      def check_captcha
        return if verify_recaptcha

        self.resource = resource_class.new sign_up_params
        resource.validate # Look for any other validation errors besides reCAPTCHA
        set_minimum_password_length
        respond_with_navigational(resource) { render :new }
      end
    end
  end
end
