# frozen_string_literal: true

module Ugrp
  class Domain < ActiveRecord::Base
    # self.table_name = 'ugrp_domains'

    belongs_to :domain_owner, polymorphic: true, optional: true

    # has_and_belongs_to_many :domain_aliases
    has_many :domain_aliases, class_name: 'Ugrp::DomainAlias', dependent: :destroy

    # has_and_belongs_to_many :users
    has_many :user_domains, class_name: 'Ugrp::UserDomain', dependent: :destroy
    has_many :users, class_name: 'Ugrp::User', through: :user_domains

    has_many :user_permissions, class_name: 'Ugrp::UserPermission', dependent: :destroy
    has_many :associated_user_permissions, class_name: 'Ugrp::Permission', through: :user_permissions

    # has_and_belongs_to_many :groups
    has_many :groups, class_name: 'Ugrp::Group', dependent: :destroy
    has_many :group_permissions, class_name: 'Ugrp::GroupPermission', dependent: :destroy
    has_many :associated_group_permissions, class_name: 'Ugrp::Permission', through: :group_permissions

    # has_and_belongs_to_many :roles
    has_many :roles, class_name: 'Ugrp::Role', dependent: :destroy
    has_many :role_permissions, class_name: 'Ugrp::RolePermission', dependent: :destroy
    has_many :associated_role_permissions, class_name: 'Ugrp::Permission', through: :role_permissions

    # has_and_belongs_to_many :permissions
    has_many :permissions, class_name: 'Ugrp::Permission', dependent: :destroy

    #------------------------------------------------------------------

    # attr_accessible :url, :name, :default_locale, :is_active
    # attr_accessible :owner, :owner_id, :owner_type

    #------------------------------------------------------------------

    validates :name, presence: true
    # validates :name, :url, uniqueness: true

    #------------------------------------------------------------------

    # Handlers for polymorphic references (using Global ID)

    # Use :to_global_id to populate forms
    def domain_owner_gid
      domain_owner&.to_global_id
    end

    # Set the attribute from a Global ID (handles the form submission)
    def domain_owner_gid=(gid)
      self.domain_owner = GlobalID::Locator.locate gid
    end

    #---------------------------------------------------------------------------

    def self.get_domain_from_request(request_host = nil)
      domain = if request_host.nil? || request_host == 'localhost' || request_host == 'test.host'
                 Ugrp::Domain.default_domain
               else
                 Ugrp::Domain.find_by(url: request_host)
               end

      if domain.nil?
        domain_alias = Ugrp::DomainAlias.find_by(url: request_host)
        unless domain_alias.nil?
          domain = domain_alias.domain
          Rails.logger.debug do
            "Ugrp::Domain::get_domain_from_request : '#{request_host}' is an alias for '#{domain.url.nil? ? 'default' : domain.url}'"
          end
        end

        if domain.nil?
          Rails.logger.debug "Ugrp::Domain::get_domain_from_request : current_domain cannot be determined fallback to 'default'"
          domain = default_domain
        end
      end

      domain
    end

    #---------------------------------------------------------------------------

    def self.default_domain
      Ugrp::Domain.find_by(url: nil)
    end

    #---------------------------------------------------------------------------

    def associated_users
      users
    end

    def active_users
      users.where(is_active: true)
    end

    def active_and_confirmed_users
      active_users.where.not(confirmed_at: nil)
    end

    #---------------------------------------------------------------------------

    def to_s
      name.to_s + (url.nil? ? '' : " (#{url})")
    end
  end
end
