# frozen_string_literal: true

module Ugrp
  class Group < ActiveRecord::Base
    # self.table_name = 'ugrp_groups'

    belongs_to :domain, class_name: 'Ugrp::Domain'

    # has_and_belongs_to_many :users, join_table: "user_groups"
    has_many :user_groups, class_name: 'Ugrp::UserGroup', dependent: :destroy
    accepts_nested_attributes_for :user_groups
    has_many :users, through: :user_groups, class_name: 'Ugrp::User'
    accepts_nested_attributes_for :users

    # has_and_belongs_to_many :roles, join_table: "group_roles"
    has_many :group_roles, class_name: 'Ugrp::GroupRole', dependent: :destroy
    accepts_nested_attributes_for :group_roles
    has_many :roles, through: :group_roles, class_name: 'Ugrp::Role'
    accepts_nested_attributes_for :roles

    # has_and_belongs_to_many :permissions
    # has_and_belongs_to_many :permissions, through: :group_permissions, class_name: 'Ugrp::Permission'
    has_many :group_permissions, class_name: 'Ugrp::GroupPermission', dependent: :destroy
    accepts_nested_attributes_for :group_permissions
    has_many :permissions, through: :group_permissions, class_name: 'Ugrp::Permission'
    accepts_nested_attributes_for :permissions

    has_many :acl_mappings, foreign_key: :group_or_role_id, class_name: 'Ugrp::AclMapping', dependent: :destroy

    #---------------------------------------------------------------------------

    # attr_accessible :domain, :domain_id
    # attr_accessible :name, :descriptive_name, :is_active

    #---------------------------------------------------------------------------

    # validates :domain, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)
    validates :name, presence: true
    validates :descriptive_name, presence: true

    #---------------------------------------------------------------------------

    def to_s
      name
    end
  end
end
