# frozen_string_literal: true

module Ugrp
  class Permission < ActiveRecord::Base
    # self.table_name = 'ugrp_permissions'

    belongs_to :domain, class_name: 'Ugrp::Domain'

    # has_and_belongs_to_many :users, join_table: "user_permissions"
    has_many :user_permissions, class_name: 'Ugrp::UserPermission', dependent: :destroy
    has_many :users, through: :user_permissions, class_name: 'Ugrp::User'

    # has_and_belongs_to_many :roles, join_table: "role_permissions"
    has_many :role_permissions, class_name: 'Ugrp::RolePermission', dependent: :destroy
    has_many :roles, through: :role_permissions, class_name: 'Ugrp::Role'

    # has_and_belongs_to_many :groups, join_table: "group_permissions"
    has_many :group_permissions, class_name: 'Ugrp::GroupPermission', dependent: :destroy
    has_many :groups, through: :group_permissions, class_name: 'Ugrp::Group'

    #---------------------------------------------------------------------------

    # attr_accessible :domain, :domain_id
    # attr_accessible :name, :descriptive_name, :is_active

    #---------------------------------------------------------------------------

    # validates :domain, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)
    validates :name, presence: true
    validates :descriptive_name, presence: true
    validates :object_name, presence: true

    #---------------------------------------------------------------------------

    def to_s
      result = "#{name}:"
      result += field_name.blank? ? "#{object_name}:" : "#{object_name}(#{field_name}):"
      result += (can_create ? 'C' : '-')
      result += (can_read   ? 'R' : '-')
      result += (can_update ? 'U' : '-')
      result += (can_delete ? 'D' : '-')
      result
    end
  end
end
