# frozen_string_literal: true

module Ugrp
  class Role < ActiveRecord::Base
    # self.table_name = 'ugrp_roles'

    belongs_to :domain, class_name: 'Ugrp::Domain'

    # has_and_belongs_to_many :users, join_table: "roles_users"
    has_many :user_roles, class_name: 'Ugrp::UserRole', dependent: :destroy
    accepts_nested_attributes_for :user_roles
    has_many :users, through: :user_roles, class_name: 'Ugrp::User'
    accepts_nested_attributes_for :users

    # has_and_belongs_to_many :groups
    # has_and_belongs_to_many :groups, through: :group_roles, class_name: 'Ugrp::Group'
    has_many :group_roles, class_name: 'Ugrp::GroupRole', dependent: :destroy
    accepts_nested_attributes_for :group_roles
    has_many :groups, through: :group_roles, class_name: 'Ugrp::Group'
    accepts_nested_attributes_for :groups

    # has_and_belongs_to_many :permissions
    # has_and_belongs_to_many :permissions, through: :role_permissions, class_name: 'Ugrp::Permission'
    has_many :role_permissions, class_name: 'Ugrp::RolePermission', dependent: :destroy
    accepts_nested_attributes_for :role_permissions
    has_many :permissions, through: :role_permissions, class_name: 'Ugrp::Permission'
    accepts_nested_attributes_for :permissions

    has_many :acl_mappings, foreign_key: :group_or_role_id, class_name: 'Ugrp::AclMapping', dependent: :destroy

    #---------------------------------------------------------------------------

    # attr_accessible :domain, :domain_id
    # attr_accessible :name, :descriptive_name, :is_active

    #---------------------------------------------------------------------------

    # validates :domain, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)
    validates :name, presence: true
    validates :descriptive_name, presence: true

    #---------------------------------------------------------------------------

    def to_s
      name
    end
  end
end
