Ugrp::Engine.routes.draw do
  #
  # API routes
  #

  namespace :api do
    resources :domains do
      resources :users
      resources :groups
      resources :roles
      resources :permissions
    end

    resources :users do
      resources :domains
    end

    resources :user_preferences

    resources :groups do
      resources :users
    end

    resources :roles do
      resources :users
    end

    resources :permissions do
      resources :groups
      resources :users
    end

    resources :acl_mappings
  end

  #
  # UI routes
  #

  # authenticated :user do
  #  root to: 'dashboard#index'
  # end

  if Gem.loaded_specs.key?('omniauth')
    devise_for :users, {
      class_name: 'Ugrp::User',
      module: :devise,
      controllers: {
        registrations: 'ugrp/users/registrations',
        confirmations: 'ugrp/users/confirmations',
        sessions: 'ugrp/users/sessions',
        passwords: 'ugrp/users/passwords',
        omniauth_callbacks: 'ugrp/users/omniauth_callbacks'
      },
      path_names: {
        sign_in: 'login',
        sign_out: 'logout',
        sign_up: 'register'
      }
    }
  else
    devise_for :users, {
      class_name: 'Ugrp::User',
      module: :devise,
      controllers: {
        registrations: 'ugrp/users/registrations',
        confirmations: 'ugrp/users/confirmations',
        sessions: 'ugrp/users/sessions',
        passwords: 'ugrp/users/passwords'
        # omniauth_callbacks: 'ugrp/users/omniauth_callbacks'
      },
      path_names: {
        sign_in: 'login',
        sign_out: 'logout',
        sign_up: 'register'
      }
    }
  end

  # match "/login(/:path)"  => 'application#login', as: :login
  # match "/logout(/:path)" => 'application#logout', as: :logout

  resources :domains

  resources :users, only: [:index, :show]
  resources :user_preferences

  resources :groups
  resources :roles
  resources :permissions
  resources :acl_mappings

  get 'dashboard' => 'dashboard#index'

  root to: 'landing_page#index'
end
