class UgrpInitialSchema < ActiveRecord::Migration[4.2]
  def change
    ActiveRecord::Base.transaction do
      create_table :ugrp_domains do |t|
        t.string :name
        t.string :url
        t.string :default_locale
        t.boolean :is_active, default: false, null: false

        t.belongs_to :domain_owner, polymorphic: true, null: true

        t.timestamps null: false
      end

      add_index :ugrp_domains, :name,                       unique: true
      add_index :ugrp_domains, :url,                        unique: true

      create_table :ugrp_domain_aliases do |t|
        t.string :url
        t.boolean :is_active, default: false, null: false

        t.references :domain, null: false

        t.timestamps null: false
      end

      add_index :ugrp_domain_aliases, :url, unique: true

      create_table :ugrp_users do |t|
        t.string :name

        ## Database authenticatable
        # t.database_authenticatable null: false
        t.string :email,              null: false, default: ""
        t.string :encrypted_password, null: false, default: "", limit: 128

        ## Recoverable
        # t.recoverable
        t.string   :reset_password_token
        t.datetime :reset_password_sent_at

        ## Rememberable
        # t.rememberable
        t.datetime :remember_created_at

        ## Trackable
        # t.trackable
        t.integer  :sign_in_count, null: false, default: 0
        t.datetime :current_sign_in_at
        t.datetime :last_sign_in_at

        if inet_available?
          t.inet :current_sign_in_ip
          t.inet :last_sign_in_ip
        else
          t.string :current_sign_in_ip
          t.string :last_sign_in_ip
        end

        ## Encryptable
        # t.encryptable
        # t.string :password_salt

        ## Confirmable
        # t.confirmable
        t.string   :confirmation_token
        t.datetime :confirmed_at
        t.datetime :confirmation_sent_at
        t.string   :unconfirmed_email # Only if using reconfirmable

        ## Lockable
        # t.lockable lock_strategy: :failed_attempts, unlock_strategy: :both
        t.integer  :failed_attempts, default: 0 # Only if lock strategy is :failed_attempts
        t.string   :unlock_token # Only if unlock strategy is :email or :both
        t.datetime :locked_at

        ## Token authenticatable
        # t.token_authenticatable
        t.string   :authentication_token
        t.datetime :authentication_token_created_at

        ## Invitable
        # t.invitable
        # t.string :invitation_token

        # CAS authenticable
        # t.cas_authenticatable
        t.string :username, null: false, default: ""

        # omniauth support
        # t.omniauthable
        t.string :provider
        t.string :uid

        t.belongs_to :user_account_owner, polymorphic: true, null: true

        t.boolean :is_active, default: true

        t.timestamps null: false
      end

      add_index :ugrp_users, :email,                unique: true
      add_index :ugrp_users, :username,             unique: true
      add_index :ugrp_users, :reset_password_token, unique: true
      # add_index :ugrp_users, :confirmation_token,   unique: true
      # add_index :ugrp_users, :unlock_token,         unique: true
      add_index :ugrp_users, :authentication_token, unique: true

      create_table :ugrp_groups do |t|
        t.references :domain, null: false
        t.string :name, null: false # , unique: true
        t.string :descriptive_name, null: false
        t.boolean :is_active, default: true

        t.timestamps null: false
      end

      add_index :ugrp_groups, [:domain_id]
      add_index :ugrp_groups, [:domain_id, :name], unique: true

      create_table :ugrp_roles do |t|
        t.references :domain, null: false
        t.string :name, null: false # , unique: true
        t.string :descriptive_name, null: false
        t.boolean :is_active, default: true

        t.timestamps null: false
      end

      add_index :ugrp_roles, [:domain_id]
      add_index :ugrp_roles, [:domain_id, :name], unique: true

      create_table :ugrp_permissions do |t|
        t.references :domain, null: false
        t.string :name, null: false # , unique: true
        t.string :descriptive_name, null: false
        t.boolean :is_active, default: true

        t.string  :object_name
        t.string  :field_name

        t.boolean :can_create, default: false, null: false
        t.boolean :can_read, default: false, null: false
        t.boolean :can_update, default: false, null: false
        t.boolean :can_delete, default: false, null: false

        t.timestamps null: false
      end

      add_index :ugrp_permissions, [:domain_id]
      add_index :ugrp_permissions, [:domain_id, :name], unique: true

      create_table :ugrp_user_domains do |t|
        t.integer :user_id, null: false # , references: :users
        t.integer :domain_id, null: false # , references: :domains
      end

      add_index :ugrp_user_domains, [:user_id, :domain_id], unique: true

      create_table :ugrp_user_groups do |t|
        t.integer :user_id, null: false # , references: :users
        t.integer :group_id, null: false # , references: :groups
        # t.timestamps
      end

      add_index :ugrp_user_groups, [:user_id, :group_id], unique: true

      create_table :ugrp_user_roles do |t|
        t.integer :user_id, null: false # , references: :users
        t.integer :role_id, null: false # , references: :roles
        # t.timestamps null: false
      end

      add_index :ugrp_user_roles, [:user_id, :role_id], unique: true

      create_table :ugrp_user_permissions do |t|
        t.integer :user_id, null: false # , references: :users
        t.integer :permission_id, null: false # , references: :permissions
        # t.timestamps null: false
      end

      add_index :ugrp_user_permissions, [:user_id, :permission_id], unique: true

      create_table :ugrp_group_permissions do |t|
        t.integer :group_id, null: false # , references: :groups
        t.integer :permission_id, null: false # , references: :permissions
        # t.timestamps null: false
      end

      add_index :ugrp_group_permissions, [:group_id, :permission_id], unique: true

      create_table :ugrp_group_roles do |t|
        t.integer :group_id, null: false # , references: :groups
        t.integer :role_id, null: false # , references: :roles
        # t.timestamps
      end

      add_index :ugrp_group_roles, [:group_id, :role_id], unique: true

      create_table :ugrp_role_permissions do |t|
        t.integer :role_id, null: false # , references: :roles
        t.integer :permission_id, null: false # , references: :permissions
        # t.timestamps null: false
      end

      add_index :ugrp_role_permissions, [:role_id, :permission_id], unique: true

      create_table :ugrp_user_preferences do |t|
        t.references :user, null: false
        t.string :key, null: false
        t.string :value

        t.timestamps null: false
      end

      add_index :ugrp_user_preferences, :user_id
      add_index :ugrp_user_preferences, [:user_id, :key], unique: true

      create_table :ugrp_acl_mappings do |t|
        t.references :group_or_role, polymorphic: true

        t.string :object_name
        t.string :field_name

        t.boolean :can_create, default: false, null: false
        t.boolean :can_read, default: false, null: false
        t.boolean :can_update, default: false, null: false
        t.boolean :can_delete, default: false, null: false

        t.timestamps null: false
      end

      # add_index :ugrp_acl_mappings, [:group_or_role_id, :group_or_role_type], { name: :index_ugrp_acl_mappings_on_group_or_role }
      # add_index :ugrp_acl_mappings, [:group_or_role_id, :group_or_role_type, :object_name, :field_name], { name: :ugrp_acl_mapping_group_or_role_object_field_index, unique: true }
      add_index :ugrp_acl_mappings, [:group_or_role_id, :group_or_role_type], name: :index_ugrp_acl_mappings_on_group_or_role
      add_index :ugrp_acl_mappings, [:group_or_role_id, :group_or_role_type, :object_name, :field_name],
                name: :ugrp_acl_mapping_group_or_role_object_field_index, unique: true
    end
  end

  def ip_column(field_name)
    if inet_available?
      (t.inet field_name)
    else
      (t.string field_name)
    end
  end

  def inet_available?
    rails4? && postgresql?
  end

  def rails4?
    Rails.version.start_with? '4'
  end

  def postgresql?
    ActiveRecord::Base.connection.adapter_name.casecmp('postgresql').zero?
  end
end
