# To use the mattr functions, ActiveSupport dependencies are required.
require 'active_support/dependencies'

require 'omniauth'

# Omniauth
require 'omniauth'
require 'omniauth-cas'
require 'omniauth-identity'
require 'omniauth-ldap'
require 'omniauth-oauth'
require 'omniauth-oauth2'

# CanCanCan
require 'cancancan'

module Ugrp
  autoload :DomainHelper, 'ugrp/domain_helper'

  module Controllers
    autoload :ApplicationControllerExtensions, 'ugrp/controllers/application_controller_extensions'
  end

  module Helpers
    autoload :ApplicationHelperExtensions, 'ugrp/helpers/application_helper_extensions'
  end

  # The parent controller all engine controllers inherits from.
  # Defaults to ApplicationController. This should be set early
  # in the initialisation process and should be set to a string.
  mattr_accessor :parent_controller
  self.parent_controller = "ApplicationController"

  # Our host application root path
  # We set this when the engine is initialised
  # mattr_accessor :app_root
  # self.app_root = 'xyz'

  # Our host application name
  # Used for the <title>
  mattr_accessor :app_title
  self.app_title = 'UGRP'

  # Attributes for authentication
  mattr_accessor :login_uri_path
  self.login_uri_path = nil

  mattr_accessor :logout_uri_path
  self.logout_uri_path = nil

  mattr_accessor :registrations_uri_path
  self.registrations_uri_path = nil


  mattr_accessor :mailer_sender
  self.mailer_sender = nil


  mattr_accessor :cas_host
  self.cas_host = nil

  mattr_accessor :cas_use_ssl
  self.cas_use_ssl = false


  mattr_accessor :ldap_host
  self.ldap_host = nil

  mattr_accessor :ldap_use_tls
  self.ldap_use_tls = false

  mattr_accessor :ldap_use_ssl
  self.ldap_use_ssl = false

  mattr_accessor :ldap_base_dn
  self.ldap_base_dn = nil

  mattr_accessor :ldap_users_base_dn
  self.ldap_users_base_dn = nil

  mattr_accessor :ldap_groups_base_dn
  self.ldap_groups_base_dn = nil


  mattr_accessor :oauth_host
  self.oauth_host = nil

  mattr_accessor :oauth_use_ssl
  self.oauth_use_ssl = false


  mattr_accessor :oauth2_host
  self.oauth2_host = nil

  mattr_accessor :oauth2_use_ssl
  self.oauth2_use_ssl = false


  mattr_accessor :perform_authentication
  self.perform_authentication = false

  mattr_accessor :alternate_domain_resolver
  self.alternate_domain_resolver = nil


  # Default way to setup the engine.
  #
  # Run 'rails generate ugrp:install' to create a fresh initialiser with all
  # configuration values.
  def self.setup
    yield self
  end

  # class Getter
  #   def initialize name
  #     @name = name
  #   end

  #   def get
  #     ActiveSupport::Dependencies.constantize(@name)
  #   end
  # end

  # def self.ref(arg)
  #   if defined?(ActiveSupport::Dependencies::ClassCache)
  #     ActiveSupport::Dependencies::reference(arg)
  #     Getter.new(arg)
  #   else
  #     ActiveSupport::Dependencies.ref(arg)
  #   end
  # end

  def self.omniauth(provider, *args)
    Devise.setup do |config|
      # strategy_class = case provider.to_sym
      # when :cas
      #  ::OmniAuth::Strategies::CAS
      # when :ldap
      #  ::OmniAuth::Strategies::LDAP
      # when :oauth, :strategy_class
      #  ::OmniAuth::Strategies::OAuth
      # when :oauth2, :strategy_class
      #  ::OmniAuth::Strategies::OAuth2
      # end

      # config.omniauth provider.to_sym, strategy_class: strategy_class, *args

      config.omniauth provider.to_sym, *args
    end
  end

  def railtie_name
    Ugrp::Engine.railtie_name
  end

  def mounted_path
    Ugrp::Engine.mounted_path
  end

  def root_path
    Ugrp::Engine.root
  end
end

# Require our engine
require "ugrp/version"
require "ugrp/engine"
