module Ugrp
  module Helpers
    # These are convenience methods to add to the ApplicationHelper
    # Define authentication filters and accessor helpers based on mappings.
    # These filters should be used inside the controllers as before_filters,
    # so you can control the scope of the user who should be signed in to
    # access that specific controller/action.
    # Example:
    #
    #   Roles:
    #     User
    #     Admin
    #
    #   Generated methods:
    #     authenticate_user!  # Signs user in or redirect
    #     authenticate_admin! # Signs admin in or redirect
    #     user_signed_in?     # Checks whether there is a user signed in or not
    #     admin_signed_in?    # Checks whether there is an admin signed in or not
    #     current_user        # Current signed in user
    #     current_admin       # Current signed in admin
    #     user_session        # Session data available only to the user scope
    #     admin_session       # Session data available only to the admin scope
    #
    #   Use:
    #     before_filter :authenticate_user!  # Tell devise to use :user map
    #     before_filter :authenticate_admin! # Tell devise to use :admin map
    #
    module ApplicationHelperExtensions

      module ClassMethods
      end

      module InstanceMethods
        def login_path
          ugrp.new_user_session_path
        end

        def logout_path
          ugrp.destroy_user_session_path
        end

        def register_path
          ugrp.new_user_registration_path
        end

        def edit_user_registration_path
          ugrp.edit_user_registration_path
        end
      end

    end
  end
end
